package orderservicelogic

import (
	model "app-cloudep-order-server/internal/model/mongo"
	ers "code.30cm.net/digimon/library-go/errs"
	"context"
	"fmt"

	"app-cloudep-order-server/gen_result/pb/tweeting"
	"app-cloudep-order-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type ListOrderLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewListOrderLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ListOrderLogic {
	return &ListOrderLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

type GetOrderListReq struct {
	PageIndex int64 `json:"page_index" validate:"required"`
	PageSize  int64 `json:"page_size" validate:"required"`

	ReferenceID   string  `json:"reference_id"`
	ReferenceUID  string  `json:"reference_uid"`
	BusinessID    string  `json:"business_id"`
	UID           string  `json:"uid"`
	OrderType     int     `json:"order_type"`
	DirectionType []int64 `json:"direction_type"`
	OrderStatus   []int64 `json:"order_status"`

	StartCreateTime       int64 `json:"start_create_time"`
	EndCreateTime         int64 `json:"end_create_time"`
	StartUpdateTime       int64 `json:"start_update_time"`
	EndUpdateTime         int64 `json:"end_update_time"`
	StartOrderArrivalTime int64 `json:"start_order_arrival_time"`
	EndOrderArrivalTime   int64 `json:"end_order_arrival_time"`
	StartOrderPaymentTime int64 `json:"start_order_payment_time"`
	EndOrderPaymentTime   int64 `json:"end_order_payment_time"`

	CryptoType string `json:"crypto_type"`
	TxHash     string `json:"tx_hash"`
}

// ListOrder 取得訂單列表
func (l *ListOrderLogic) ListOrder(in *tweeting.ListOrderReq) (*tweeting.ListOrderResp, error) {
	// 驗證資料，目前只有 Page 必帶，其他要驗證在驗證
	if err := l.svcCtx.Validate.ValidateAll(&GetOrderListReq{
		PageIndex: in.GetPageIndex(),
		PageSize:  in.GetPageSize(),
	}); err != nil {
		// 錯誤代碼 06-011-00
		return nil, ers.InvalidFormat(err.Error())
	}

	orders, total, err := l.svcCtx.OrderModel.ListOrder(l.ctx, model.GetOrderListReq{})
	if err != nil {
		return nil, err
	}

	fmt.Println(orders, total)
	return &tweeting.ListOrderResp{}, nil
}
